/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the PasteIP extension for Firefox and other Mozilla products.
 *
 * The Initial Developer of the Original Code is Michael Newton.
 * Portions created by the Initial Developer are Copyright (C) 2003-2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// No need to make this an object, but it's safer to avoid possible duplicate function names (v0.0)
var pasteip = {
	init: function() {
		var menu = document.getElementById('contentAreaContextMenu');
		if (menu) menu.addEventListener('popupshowing', pasteip.showHide, false);
	},

// Instead of setting up complex checking for a textbox, let's just show the items if the "Undo" item is shown (v0.0)
	showHide: function() {
		document.getElementById('context-pasteip').hidden = document.getElementById('context-undo').hidden;
		document.getElementById('context-pasteua').hidden = document.getElementById('context-undo').hidden;
	},

// Thanks to mozillazine forum user Torisugari for pointing me to this XPCOM interface as an alternative to using Java! (v1.0)
	pasteAddress: function(isMail) {
		var DNSService=Components.classes["@mozilla.org/network/dns-service;1"].getService(Components.interfaces.nsIDNSService);
// After 11 September we can't get the IP address directly (v1.1)
//		var theAddress = DNSService.myIPAddress;
// So we'll get the hostname and resolve it. (v1.1)
		var DNSRecord=DNSService.resolve(DNSService.myHostName, true);
// This may return more than one IP, so load them into an array (v1.1)
		allIP = new Array(1);
		for (i=0;DNSRecord.hasMore();i++) allIP[i]=DNSRecord.getNextAddrAsString();
// Then check prefs to see which one to put in the textbox (v1.3)
		const preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("");
		if (preferencesService.prefHasUserValue("pasteip.ipaddress.select")) {
			whichIP = preferencesService.getIntPref("pasteip.ipaddress.select");
		}
		else whichIP = 0;
// Make sure nobody puts a stupid value in the pref (v1.3)
		var theAddress=(whichIP < allIP.length)?allIP[whichIP]:allIP[0];
// Make the change in mail (v1.3)
		if (isMail == 1) {
			theEditor = GetCurrentEditor();
  			if (theEditor) theEditor.insertText(theAddress);
		}
// Make the change (v0.0)
		else {
//			var theBox = document.commandDispatcher.focusedElement;
//			theBox.value = theBox.value + theAddress;
// instead of tacking it on the end, we'll insert it at the cursor position (v1.4)
			pasteip.insertString(document.commandDispatcher.focusedElement, theAddress);
		}
	},

	pasteUA: function(isMail) {
		var ua = navigator.userAgent;
		if (isMail == 1) {
			theEditor = GetCurrentEditor();
  			if (theEditor) theEditor.insertText(ua);
		}
		else {
//			var theBox = document.commandDispatcher.focusedElement;
//			theBox.value = theBox.value + ua;
			pasteip.insertString(document.commandDispatcher.focusedElement, ua);
		}
	},
// adapted from http://www.alexking.org/blog/2003/06/02/inserting-at-the-cursor-using-javascript/ (v1.4)
	insertString: function(theBox, theAddress) {
// even if there's no actual selection, we can still get cursor position assuming a zero length selection
		var curPos = theBox.selectionEnd;
// then it's just a simple matter of substrings before and after that position
		theBox.value = theBox.value.substring(0, curPos) + theAddress + theBox.value.substring(curPos, theBox.value.length);
// and we'll put the cursor at the end of the newly inserted text
		theBox.selectionStart = curPos + theAddress.length;
		theBox.selectionEnd = curPos + theAddress.length;
	},
	populatePref: function() {
		const preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("");
		if (preferencesService.prefHasUserValue("pasteip.ipaddress.select")) {
			whichIP = preferencesService.getIntPref("pasteip.ipaddress.select");
		}
		else whichIP = 0;
		document.getElementById('whichip').value=whichIP;
	},
	refreshPref: function() {
		if (!isNaN(document.getElementById('whichip').value)){
			var whichIP=document.getElementById('whichip').value
			var DNSService=Components.classes["@mozilla.org/network/dns-service;1"].getService(Components.interfaces.nsIDNSService);
			var DNSRecord=DNSService.resolve(DNSService.myHostName, true);
			var allIP = new Array(1);
			for (i=0;DNSRecord.hasMore();i++) allIP[i]=DNSRecord.getNextAddrAsString();
			var theAddress=(whichIP < allIP.length)?allIP[whichIP]:allIP[0];
			document.getElementById('ipvalue').value='IP address will be ' + theAddress;
		}
	},
	savePref: function() {
		if (!isNaN(document.getElementById('whichip').value)){
			const preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("");
			preferencesService.setIntPref("pasteip.ipaddress.select",document.getElementById('whichip').value);
		}
	},
	initPref: function() {
		if (typeof(parent.initPanel) != "undefined") parent.initPanel(window.location.href);
		else if (typeof(window.opener.top.initPanel) != "undefined") window.opener.top.initPanel(window.location.href, window);
	}
}

window.addEventListener('load', pasteip.init, false); 
